Module input

Module input 

Structs

JobAsBindGroup
JobComputePipeline
A JobInput type that sets up a ComputePipeline for a job. This component must be added to a job as it is spawned in order to setup the pipeline.
JobRenderPipeline
A JobInput type that sets up a RenderPipeline for a job. This component must be added to a job as it is spawned in order to setup the pipeline.
PreparedJobBindGroup
A JobInput type that prepares the graphics job type itself as a bind group, using its AsBindGroup implementation.

Enums

JobInputStatus
The status of a job input

Traits

JobInput
A trait describing input to a graphics job.

Type Aliases

JobInputItem