Structs
- JobAs
Bind Group - JobCompute
Pipeline - A
JobInputtype that sets up aComputePipelinefor a job. This component must be added to a job as it is spawned in order to setup the pipeline. - JobRender
Pipeline - A
JobInputtype that sets up aRenderPipelinefor a job. This component must be added to a job as it is spawned in order to setup the pipeline. - Prepared
JobBind Group - A
JobInputtype that prepares the graphics job type itself as a bind group, using itsAsBindGroupimplementation.
Enums
- JobInput
Status - The status of a job input
Traits
- JobInput
- A trait describing input to a graphics job.